//
//  ComposeUIConfig.swift
//  ComposeUI
//
//  Created by Shadowfacts on 3/4/23.
//

import SwiftUI
import Pachyderm
import PhotosUI
import PencilKit

public struct ComposeUIConfig {
    public var backgroundColor = Color(uiColor: .systemBackground)
    public var groupedBackgroundColor = Color(uiColor: .systemGroupedBackground)
    public var groupedCellBackgroundColor = Color(uiColor: .systemBackground)
    public var fillColor = Color(uiColor: .systemFill)
    public var avatarStyle = AvatarStyle.roundRect
    public var useTwitterKeyboard = false
    public var contentType = StatusContentType.plain
    public var automaticallySaveDrafts = false
    public var requireAttachmentDescriptions = false
    
    public var dismiss: @MainActor (DismissMode) -> Void = { _ in }
    public var presentAssetPicker: ((@MainActor @escaping ([PHPickerResult]) -> Void) -> Void)?
    public var presentDrawing: ((PKDrawing, @escaping (PKDrawing) -> Void) -> Void)?
    public var userActivityForDraft: ((Draft) -> NSItemProvider?) = { _ in nil }
    
    public init() {
    }
}

extension ComposeUIConfig {
    public enum AvatarStyle: Equatable {
        case roundRect, circle
        
        var cornerRadiusFraction: CGFloat {
            switch self {
            case .roundRect:
                return 0.1
            case .circle:
                return 0.5
            }
        }
    }
}
